@@ -1,5 +1,6 @@
 from typing import Any, Optional, Sequence
 
+from pandas_profiling.config import Style
 from pandas_profiling.report.presentation.core.item_renderer import ItemRenderer
 
 
@@ -7,12 +8,15 @@ class Table(ItemRenderer):
     def __init__(
         self,
         rows: Sequence,
+        style: Style,
         name: Optional[str] = None,
         caption: Optional[str] = None,
         **kwargs
     ):
         super().__init__(
-            "table", {"rows": rows, "name": name, "caption": caption}, **kwargs
+            "table",
+            {"rows": rows, "name": name, "caption": caption, "style": style},
+            **kwargs
         )
 
     def __repr__(self) -> str:
