@@ -19,6 +19,8 @@ class HTMLAlerts(Alerts):
             "skewed": "info",
             "high_correlation": "default",
             "duplicates": "default",
+            "non_stationary": "default",
+            "seasonal": "default",
         }
 
         return templates.template("alerts.html").render(**self.content, styles=styles)
