@@ -3,6 +3,7 @@ from pandas_profiling.report.presentation.flavours.widget.collapse import Widget
 from pandas_profiling.report.presentation.flavours.widget.container import (
     WidgetContainer,
 )
+from pandas_profiling.report.presentation.flavours.widget.dropdown import WidgetDropdown
 from pandas_profiling.report.presentation.flavours.widget.duplicate import (
     WidgetDuplicate,
 )
@@ -29,6 +30,7 @@ __all__ = [
     "WidgetCollapse",
     "WidgetContainer",
     "WidgetDuplicate",
+    "WidgetDropdown",
     "WidgetFrequencyTable",
     "WidgetFrequencyTableSmall",
     "WidgetHTML",
